/* eslint-disable @typescript-eslint/no-explicit-any */
import { OT_Type, SharedDoc } from "@grapecity-software/js-collaboration-ot-client";
import {Presence} from "@grapecity-software/js-collaboration-presence-client";
/**
 * The ot type of spread-sheets.
 */
export declare const type: OT_Type;

export interface IOpComponent {
    type: string;
}

export interface IChangeSet {
    ops: IOpComponent[];
}

/**
 * Binds workbook with the document.
 * @param workbook - The instance of GC.Spread.Sheets.Workbook.
 * @param doc - The instance of SharedDoc.
 */
export declare function bind(workbook: any, doc: SharedDoc<any, IChangeSet>): void;

export interface ISelections {
    selections?: Range[];
    sheetId?: string;
}

export enum BrowsingMode {
    edit,
    view
}


export interface IPermission {
    mode: BrowsingMode;
}

export interface IUser {
    id: string;
    name: string;
    color?: string;
    permission?: IPermission;
}

export interface IPresence {
    user: IUser;
    status: {
        selections?: ISelections;
    };
}

export interface IBindPresenceOptions {
    onPresencesUpdate?: (presences?: IPresence[]) => void;
    colorScheme?: string[];
}
/**
 * Binds workbook with the presence.
 * @param workbook - The instance of GC.Spread.Sheets.Workbook.
 * @param {Presence} presence - The instance of Presence.
 * @param {IUser} user - The user info.
 * @param {IBindPresenceOptions} [options] - The bind presence options.
 */
export declare function bindPresence(workbook: any, presence: Presence<IPresence>, user: IUser, options?: IBindPresenceOptions): void;

export interface IWorksheet {
    getId(): string;
    getSelections(): Range[];
}

export interface IPresence {
    user: IUser;
    status: {
        selections?: ISelections;
    };
}